from bs4 import BeautifulSoup
import requests, os

from uk_bin_collection.uk_bin_collection.common import *
from uk_bin_collection.uk_bin_collection.get_bin_data import AbstractGetBinDataClass


# import the wonderful Beautiful Soup and the URL grabber
class CouncilClass(AbstractGetBinDataClass):
    """
    Concrete classes have to implement all abstract operations of the
    base class. They can also override some operations with a default
    implementation.
    """

    def parse_data(self, page: str, **kwargs) -> dict:
        # Make a BS4 object

        data = {"bins": []}

        user_agent = (
            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/108.0.0.0 Safari/537.36"
        )
        headers = {"User-Agent": user_agent}

        address_street = kwargs.get("paon")

        # Stage 1 - Fetch initial page to get hidden form values needed for submission
        stage1_url = "https://apps.gedling.gov.uk/refuse/search.aspx"
        stage1_data = requests.get(
            "https://apps.gedling.gov.uk/refuse/search.aspx", headers=headers
        )

        soup = BeautifulSoup(stage1_data.text, features="html.parser")
        try:
            value_viewstate = soup.find_all("input", {"id": "__VIEWSTATE"})[0]["value"]
            value_viewstategenerator = soup.find_all(
                "input", {"id": "__VIEWSTATEGENERATOR"}
            )[0]["value"]
            value_eventvalidation = soup.find_all("input", {"id": "__EVENTVALIDATION"})[
                0
            ]["value"]
        except:
            raise Exception(
                "Beautiful Soup was not able to get the data back from the Stage 1 URL that we were expecting. Please raise an issue in GitHub"
            )

        # Stage 2 - Now POST the query to get the bin data back
        stage2_url = "https://apps.gedling.gov.uk/refuse/search.aspx"
        post_data = {
            "__VIEWSTATE": value_viewstate,
            "__VIEWSTATEGENERATOR": value_viewstategenerator,
            "__EVENTVALIDATION": value_eventvalidation,
            "ctl00$MainContent$street": address_street,
            "ctl00$MainContent$mybutton": "Search",
        }

        stage2_request = requests.post(stage2_url, data=post_data, headers=headers)

        soup = BeautifulSoup(stage2_request.text, features="html.parser")
        try:
            bin_refuse_calendar = os.path.basename(
                soup.find_all(
                    "a", {"id": "ctl00_MainContent_streetgridview_ctl02_calendar1"}
                )[0]["href"]
            )
            bin_garden_calendar = os.path.basename(
                soup.find_all(
                    "a", {"id": "ctl00_MainContent_gardenGridView_ctl02_calendar2"}
                )[0]["href"]
            )
        except:
            raise Exception(
                "No results for address lookup found. If correct address is being used, please raise a GitHub issue"
            )

        bin_data = self.get_manual_data(bin_refuse_calendar, bin_garden_calendar)

        for k, v in bin_data.items():
            for date in v:
                dict_data = {"type": k, "collectionDate": date}

                data["bins"].append(dict_data)

        return data

    def get_manual_data(self, refuse, garden):
        # Function to hold all the manual bin data extracted from the PDF's

        raw_data = {
            "refuse": {
                "MondayG1-2024.pdf": {
                    "Black Bin": [
                        "04/12/2023",
                        "16/12/2023",
                        "30/12/2023",
                        "15/01/2024",
                        "29/01/2024",
                        "12/02/2024",
                        "26/02/2024",
                        "11/03/2024",
                        "25/03/2024",
                        "08/04/2024",
                        "22/04/2024",
                        "04/05/2024",
                        "20/05/2024",
                        "03/06/2024",
                        "17/06/2024",
                        "01/07/2024",
                        "15/07/2024",
                        "29/07/2024",
                        "12/08/2024",
                        "24/08/2024",
                        "09/09/2024",
                        "23/09/2024",
                        "07/10/2024",
                        "21/10/2024",
                        "04/11/2024",
                        "18/11/2024",
                    ],
                    "Green Bin": [
                        "11/12/2023",
                        "22/12/2023",
                        "08/01/2024",
                        "22/01/2024",
                        "05/02/2024",
                        "19/02/2024",
                        "04/03/2024",
                        "18/03/2024",
                        "30/03/2024",
                        "15/04/2024",
                        "29/04/2024",
                        "13/05/2024",
                        "25/05/2024",
                        "10/06/2024",
                        "24/06/2024",
                        "08/07/2024",
                        "22/07/2024",
                        "05/08/2024",
                        "19/08/2024",
                        "02/09/2024",
                        "16/09/2024",
                        "30/09/2024",
                        "14/10/2024",
                        "28/10/2024",
                        "11/11/2024",
                        "25/11/2024",
                    ],
                    "Glass Box": [
                        "27/11/2023",
                        "22/12/2023",
                        "22/01/2024",
                        "19/02/2024",
                        "18/03/2024",
                        "15/04/2024",
                        "13/05/2024",
                        "10/06/2024",
                        "08/07/2024",
                        "05/08/2024",
                        "02/09/2024",
                        "30/09/2024",
                        "28/10/2024",
                        "25/11/2024",
                    ],
                },
                "MondayG2-2024.pdf": {
                    "Black Bin": [
                        "11/12/2023",
                        "22/12/2023",
                        "08/01/2024",
                        "22/01/2024",
                        "05/02/2024",
                        "19/02/2024",
                        "04/03/2024",
                        "18/03/2024",
                        "30/03/2024",
                        "15/04/2024",
                        "29/04/2024",
                        "13/05/2024",
                        "25/05/2024",
                        "10/06/2024",
                        "24/06/2024",
                        "08/07/2024",
                        "22/07/2024",
                        "05/08/2024",
                        "19/08/2024",
                        "02/09/2024",
                        "16/09/2024",
                        "30/09/2024",
                        "14/10/2024",
                        "28/10/2024",
                        "11/11/2024",
                        "25/11/2024",
                    ],
                    "Green Bin": [
                        "04/12/2023",
                        "16/12/2023",
                        "30/12/2024",
                        "15/01/2024",
                        "29/01/2024",
                        "12/02/2024",
                        "26/02/2024",
                        "11/03/2024",
                        "25/03/2024",
                        "08/04/2024",
                        "22/04/2024",
                        "04/05/2024",
                        "20/05/2024",
                        "03/06/2024",
                        "17/06/2024",
                        "01/07/2024",
                        "15/07/2024",
                        "29/07/2024",
                        "12/08/2024",
                        "24/08/2024",
                        "09/09/2024",
                        "23/09/2024",
                        "07/10/2024",
                        "21/10/2024",
                        "04/11/2024",
                        "18/11/2024",
                    ],
                    "Glass Box": [
                        "04/12/2023",
                        "30/12/2023",
                        "29/01/2024",
                        "26/02/2024",
                        "25/03/2024",
                        "22/04/2024",
                        "20/05/2024",
                        "17/06/2024",
                        "15/07/2024",
                        "12/08/2024",
                        "09/09/2024",
                        "07/10/2024",
                        "04/11/2024",
                    ],
                },
                "MondayG3-2024.pdf": {
                    "Black Bin": [
                        "04/12/2023",
                        "16/12/2023",
                        "30/12/2023",
                        "15/01/2024",
                        "29/01/2024",
                        "12/02/2024",
                        "26/02/2024",
                        "11/03/2024",
                        "25/03/2024",
                        "08/04/2024",
                        "22/04/2024",
                        "04/05/2024",
                        "20/05/2024",
                        "03/06/2024",
                        "17/06/2024",
                        "01/07/2024",
                        "15/07/2024",
                        "29/07/2024",
                        "12/08/2024",
                        "24/08/2024",
                        "09/09/2024",
                        "23/09/2024",
                        "07/10/2024",
                        "21/10/2024",
                        "04/11/2024",
                        "18/11/2024",
                    ],
                    "Green Bin": [
                        "11/12/2023",
                        "22/12/2023",
                        "08/01/2024",
                        "22/01/2024",
                        "05/02/2024",
                        "19/02/2024",
                        "04/03/2024",
                        "18/03/2024",
                        "30/03/2024",
                        "15/04/2024",
                        "29/04/2024",
                        "13/05/2024",
                        "25/05/2024",
                        "10/06/2024",
                        "24/06/2024",
                        "08/07/2024",
                        "22/07/2024",
                        "05/08/2024",
                        "19/08/2024",
                        "02/09/2024",
                        "16/09/2024",
                        "30/09/2024",
                        "14/10/2024",
                        "28/10/2024",
                        "11/11/2024",
                        "25/11/2024",
                    ],
                    "Glass Box": [
                        "11/12/2023",
                        "08/01/2024",
                        "05/02/2024",
                        "04/03/2024",
                        "30/03/2024",
                        "29/04/2024",
                        "25/05/2024",
                        "24/06/2024",
                        "22/07/2024",
                        "19/08/2024",
                        "16/09/2024",
                        "14/10/2024",
                        "11/11/2024",
                    ],
                },
                "MondayG4-2024.pdf": {
                    "Black Bin": [
                        "11/12/2023",
                        "22/12/2023",
                        "08/01/2024",
                        "22/01/2024",
                        "05/02/2024",
                        "19/02/2024",
                        "04/03/2024",
                        "18/03/2024",
                        "30/03/2024",
                        "15/04/2024",
                        "29/04/2024",
                        "13/05/2024",
                        "25/05/2024",
                        "10/06/2024",
                        "24/06/2024",
                        "08/07/2024",
                        "22/07/2024",
                        "05/08/2024",
                        "19/08/2024",
                        "02/09/2024",
                        "16/09/2024",
                        "30/09/2024",
                        "14/10/2024",
                        "28/10/2024",
                        "11/11/2024",
                        "25/11/2024",
                    ],
                    "Green Bin": [
                        "04/12/2023",
                        "16/12/2023",
                        "30/12/2023",
                        "15/01/2024",
                        "29/01/2024",
                        "12/02/2024",
                        "26/02/2024",
                        "11/03/2024",
                        "25/03/2024",
                        "08/04/2024",
                        "22/04/2024",
                        "04/05/2024",
                        "20/05/2024",
                        "03/06/2024",
                        "17/06/2024",
                        "01/07/2024",
                        "15/07/2024",
                        "29/07/2024",
                        "12/08/2024",
                        "24/08/2024",
                        "09/09/2024",
                        "23/09/2024",
                        "07/10/2024",
                        "21/10/2024",
                        "04/11/2024",
                        "18/11/2024",
                    ],
                    "Glass Box": [
                        "16/12/2023",
                        "15/01/2024",
                        "12/02/2024",
                        "11/03/2024",
                        "08/04/2024",
                        "04/05/2024",
                        "03/06/2024",
                        "01/07/2024",
                        "29/07/2024",
                        "24/08/2024",
                        "23/09/2024",
                        "21/10/2024",
                        "18/11/2024",
                    ],
                },
                "TuesdayG1-2024.pdf": {
                    "Black Bin": [
                        "05/12/2023",
                        "18/12/2023",
                        "02/01/2024",
                        "16/01/2024",
                        "30/01/2024",
                        "13/02/2024",
                        "27/02/2024",
                        "12/03/2024",
                        "26/03/2024",
                        "09/04/2024",
                        "23/04/2024",
                        "07/05/2024",
                        "21/05/2024",
                        "04/06/2024",
                        "18/06/2024",
                        "02/07/2024",
                        "16/07/2024",
                        "30/07/2024",
                        "13/08/2024",
                        "27/08/2024",
                        "10/09/2024",
                        "24/09/2024",
                        "08/10/2024",
                        "22/10/2024",
                        "05/11/2024",
                        "19/11/2024",
                    ],
                    "Green Bin": [
                        "12/12/2023",
                        "26/12/2023",
                        "09/01/2024",
                        "23/01/2024",
                        "06/02/2024",
                        "20/02/2024",
                        "05/03/2024",
                        "19/03/2024",
                        "02/04/2024",
                        "16/04/2024",
                        "30/04/2024",
                        "14/05/2024",
                        "28/05/2024",
                        "11/06/2024",
                        "25/06/2024",
                        "09/07/2024",
                        "23/07/2024",
                        "06/08/2024",
                        "20/08/2024",
                        "03/09/2024",
                        "17/09/2024",
                        "01/10/2024",
                        "15/10/2024",
                        "29/10/2024",
                        "12/11/2024",
                        "26/11/2024",
                    ],
                    "Glass Box": [
                        "23/12/2023",
                        "23/01/2024",
                        "20/02/2024",
                        "19/03/2024",
                        "16/04/2024",
                        "14/05/2024",
                        "11/06/2024",
                        "09/07/2024",
                        "06/08/2024",
                        "03/09/2024",
                        "01/10/2024",
                        "29/10/2024",
                        "26/11/2024",
                    ],
                },
                "TuesdayG2-2024.pdf": {
                    "Black Bin": [
                        "12/12/2023",
                        "23/12/2023",
                        "09/01/2024",
                        "23/01/2024",
                        "06/02/2024",
                        "20/02/2024",
                        "05/03/2024",
                        "19/03/2024",
                        "02/04/2024",
                        "16/04/2024",
                        "30/04/2024",
                        "14/05/2024",
                        "28/05/2024",
                        "11/06/2024",
                        "25/06/2024",
                        "09/07/2024",
                        "23/07/2024",
                        "06/08/2024",
                        "20/08/2024",
                        "03/09/2024",
                        "17/09/2024",
                        "01/10/2024",
                        "15/10/2024",
                        "29/10/2024",
                        "12/11/2024",
                        "26/11/2024",
                    ],
                    "Green Bin": [
                        "05/12/2023",
                        "18/12/2023",
                        "02/01/2024",
                        "16/01/2024",
                        "30/01/2024",
                        "13/02/2024",
                        "27/02/2024",
                        "12/03/2024",
                        "26/03/2024",
                        "09/04/2024",
                        "23/04/2024",
                        "07/05/2024",
                        "21/05/2024",
                        "04/06/2024",
                        "18/06/2024",
                        "02/07/2024",
                        "16/07/2024",
                        "30/07/2024",
                        "13/08/2024",
                        "27/08/2024",
                        "10/09/2024",
                        "24/09/2024",
                        "08/10/2024",
                        "22/10/2024",
                        "05/11/2024",
                        "19/11/2024",
                    ],
                    "Glass Box": [
                        "05/12/2023",
                        "02/01/2024",
                        "30/01/2024",
                        "27/02/2024",
                        "26/03/2024",
                        "23/04/2024",
                        "21/05/2024",
                        "18/06/2024",
                        "16/07/2024",
                        "13/08/2024",
                        "10/09/2024",
                        "08/10/2024",
                        "05/11/2024",
                    ],
                },
                "TuesdayG3-2024.pdf": {
                    "Black Bin": [
                        "05/12/2023",
                        "18/12/2023",
                        "02/01/2024",
                        "16/01/2024",
                        "30/01/2024",
                        "13/02/2024",
                        "27/02/2024",
                        "12/03/2024",
                        "26/03/2024",
                        "09/04/2024",
                        "23/04/2024",
                        "07/05/2024",
                        "21/05/2024",
                        "04/06/2024",
                        "18/06/2024",
                        "02/07/2024",
                        "16/07/2024",
                        "30/07/2024",
                        "13/08/2024",
                        "27/08/2024",
                        "10/09/2024",
                        "24/09/2024",
                        "08/10/2024",
                        "22/10/2024",
                        "05/11/2024",
                        "19/11/2024",
                    ],
                    "Green Bin": [
                        "12/12/2023",
                        "23/12/2023",
                        "09/01/2024",
                        "23/01/2024",
                        "06/02/2024",
                        "20/02/2024",
                        "05/03/2024",
                        "19/03/2024",
                        "02/04/2024",
                        "16/04/2024",
                        "30/04/2024",
                        "14/05/2024",
                        "28/05/2024",
                        "11/06/2024",
                        "25/06/2024",
                        "09/07/2024",
                        "23/07/2024",
                        "06/08/2024",
                        "20/08/2024",
                        "03/09/2024",
                        "17/09/2024",
                        "01/10/2024",
                        "15/10/2024",
                        "29/10/2024",
                        "12/11/2024",
                        "26/11/2024",
                    ],
                    "Glass Box": [
                        "12/12/2023",
                        "09/01/2024",
                        "06/02/2024",
                        "05/03/2024",
                        "02/04/2024",
                        "30/04/2024",
                        "28/05/2024",
                        "25/06/2024",
                        "23/07/2024",
                        "20/08/2024",
                        "17/09/2024",
                        "15/10/2024",
                        "12/11/2024",
                    ],
                },
                "TuesdayG4-2024.pdf": {
                    "Black Bin": [
                        "12/12/2023",
                        "23/12/2023",
                        "09/01/2024",
                        "23/01/2024",
                        "06/02/2024",
                        "20/02/2024",
                        "05/03/2024",
                        "19/03/2024",
                        "02/04/2024",
                        "16/04/2024",
                        "30/04/2024",
                        "14/05/2024",
                        "28/05/2024",
                        "11/06/2024",
                        "25/06/2024",
                        "09/07/2024",
                        "23/07/2024",
                        "06/08/2024",
                        "20/08/2024",
                        "03/09/2024",
                        "17/09/2024",
                        "01/10/2024",
                        "15/10/2024",
                        "29/10/2024",
                        "12/11/2024",
                        "26/11/2024",
                    ],
                    "Green Bin": [
                        "05/12/2023",
                        "18/12/2023",
                        "02/01/2024",
                        "16/01/2024",
                        "30/01/2024",
                        "13/02/2024",
                        "27/02/2024",
                        "12/03/2024",
                        "26/03/2024",
                        "09/04/2024",
                        "23/04/2024",
                        "07/05/2024",
                        "21/05/2024",
                        "04/06/2024",
                        "18/06/2024",
                        "02/07/2024",
                        "16/07/2024",
                        "30/07/2024",
                        "13/08/2024",
                        "27/08/2024",
                        "10/09/2024",
                        "24/09/2024",
                        "08/10/2024",
                        "22/10/2024",
                        "05/11/2024",
                        "19/11/2024",
                    ],
                    "Glass Box": [
                        "18/12/2023",
                        "16/01/2024",
                        "13/02/2024",
                        "12/03/2024",
                        "09/04/2024",
                        "07/05/2024",
                        "04/06/2024",
                        "02/07/2024",
                        "30/07/2024",
                        "27/08/2024",
                        "24/09/2024",
                        "22/10/2024",
                        "19/11/2024",
                    ],
                },
                "WednesdayG1-2024.pdf": {
                    "Black Bin": [
                        "06/12/2023",
                        "19/12/2023",
                        "03/01/2024",
                        "17/01/2024",
                        "31/01/2024",
                        "14/02/2024",
                        "28/02/2024",
                        "13/03/2024",
                        "27/03/2024",
                        "10/04/2024",
                        "24/04/2024",
                        "08/05/2024",
                        "22/05/2024",
                        "05/06/2024",
                        "19/06/2024",
                        "03/07/2024",
                        "17/07/2024",
                        "31/07/2024",
                        "14/08/2024",
                        "28/08/2024",
                        "11/09/2024",
                        "25/09/2024",
                        "09/10/2024",
                        "23/10/2024",
                        "06/11/2024",
                        "20/11/2024",
                    ],
                    "Green Bin": [
                        "13/12/2023",
                        "27/12/2023",
                        "10/01/2024",
                        "24/01/2024",
                        "07/02/2024",
                        "21/02/2024",
                        "06/03/2024",
                        "20/03/2024",
                        "03/04/2024",
                        "17/04/2024",
                        "01/05/2024",
                        "15/05/2024",
                        "29/05/2024",
                        "12/06/2024",
                        "26/06/2024",
                        "10/07/2024",
                        "24/07/2024",
                        "07/08/2024",
                        "21/08/2024",
                        "04/09/2024",
                        "18/09/2024",
                        "02/10/2024",
                        "16/10/2024",
                        "30/10/2024",
                        "13/11/2024",
                        "27/11/2024",
                    ],
                    "Glass Box": [
                        "27/12/2023",
                        "24/01/2024",
                        "21/02/2024",
                        "20/03/2024",
                        "17/04/2024",
                        "15/05/2024",
                        "12/06/2024",
                        "10/07/2024",
                        "07/08/2024",
                        "04/09/2024",
                        "02/10/2024",
                        "30/10/2024",
                        "27/11/2024",
                    ],
                },
                "WednesdayG2-2024.pdf": {
                    "Black Bin": [
                        "13/12/2023",
                        "27/12/2023",
                        "10/01/2024",
                        "24/01/2024",
                        "07/02/2024",
                        "21/02/2024",
                        "06/03/2024",
                        "20/03/2024",
                        "03/04/2024",
                        "17/04/2024",
                        "01/05/2024",
                        "15/05/2024",
                        "29/05/2024",
                        "12/06/2024",
                        "26/06/2024",
                        "10/07/2024",
                        "24/07/2024",
                        "07/08/2024",
                        "21/08/2024",
                        "04/09/2024",
                        "18/09/2024",
                        "02/10/2024",
                        "16/10/2024",
                        "30/10/2024",
                        "13/11/2024",
                        "27/11/2024",
                    ],
                    "Green Bin": [
                        "06/12/2023",
                        "19/12/2023",
                        "03/01/2024",
                        "17/01/2024",
                        "31/01/2024",
                        "14/02/2024",
                        "28/02/2024",
                        "13/03/2024",
                        "27/03/2024",
                        "10/04/2024",
                        "24/04/2024",
                        "08/05/2024",
                        "22/05/2024",
                        "05/06/2024",
                        "19/06/2024",
                        "03/07/2024",
                        "17/07/2024",
                        "31/07/2024",
                        "14/08/2024",
                        "28/08/2024",
                        "11/09/2024",
                        "25/09/2024",
                        "09/10/2024",
                        "23/10/2024",
                        "06/11/2024",
                        "20/11/2024",
                    ],
                    "Glass Box": [
                        "06/12/2023",
                        "03/01/2024",
                        "31/01/2024",
                        "28/02/2024",
                        "27/03/2024",
                        "24/04/2024",
                        "22/05/2024",
                        "19/06/2024",
                        "17/07/2024",
                        "14/08/2024",
                        "11/09/2024",
                        "09/10/2024",
                        "06/11/2024",
                    ],
                },
                "WednesdayG3-2024.pdf": {
                    "Black Bin": [
                        "06/12/2023",
                        "19/12/2023",
                        "03/01/2024",
                        "17/01/2024",
                        "31/01/2024",
                        "14/02/2024",
                        "28/02/2024",
                        "13/03/2024",
                        "27/03/2024",
                        "10/04/2024",
                        "24/04/2024",
                        "08/05/2024",
                        "22/05/2024",
                        "05/06/2024",
                        "19/06/2024",
                        "03/07/2024",
                        "17/07/2024",
                        "31/07/2024",
                        "14/08/2024",
                        "28/08/2024",
                        "11/09/2024",
                        "25/09/2024",
                        "09/10/2024",
                        "23/10/2024",
                        "06/11/2024",
                        "20/11/2024",
                    ],
                    "Green Bin": [
                        "13/12/2023",
                        "27/12/2023",
                        "10/01/2024",
                        "24/01/2024",
                        "07/02/2024",
                        "21/02/2024",
                        "06/03/2024",
                        "20/03/2024",
                        "03/04/2024",
                        "17/04/2024",
                        "01/05/2024",
                        "15/05/2024",
                        "29/05/2024",
                        "12/06/2024",
                        "26/06/2024",
                        "10/07/2024",
                        "24/07/2024",
                        "07/08/2024",
                        "21/08/2024",
                        "04/09/2024",
                        "18/09/2024",
                        "02/10/2024",
                        "16/10/2024",
                        "30/10/2024",
                        "13/11/2024",
                        "27/11/2024",
                    ],
                    "Glass Box": [
                        "13/12/2023",
                        "10/01/2024",
                        "07/02/2024",
                        "06/03/2024",
                        "03/04/2024",
                        "01/05/2024",
                        "29/05/2024",
                        "26/06/2024",
                        "24/07/2024",
                        "21/08/2024",
                        "18/09/2024",
                        "16/10/2024",
                        "13/11/2024",
                    ],
                },
                "WednesdayG4-2024.pdf": {
                    "Black Bin": [
                        "13/12/2023",
                        "27/12/2023",
                        "10/01/2024",
                        "24/01/2024",
                        "07/02/2024",
                        "21/02/2024",
                        "06/03/2024",
                        "20/03/2024",
                        "03/04/2024",
                        "17/04/2024",
                        "01/05/2024",
                        "15/05/2024",
                        "29/05/2024",
                        "12/06/2024",
                        "26/06/2024",
                        "10/07/2024",
                        "24/07/2024",
                        "07/08/2024",
                        "21/08/2024",
                        "04/09/2024",
                        "18/09/2024",
                        "02/10/2024",
                        "16/10/2024",
                        "30/10/2024",
                        "13/11/2024",
                        "27/11/2024",
                    ],
                    "Green Bin": [
                        "06/12/2023",
                        "19/12/2023",
                        "03/01/2024",
                        "17/01/2024",
                        "31/01/2024",
                        "14/02/2024",
                        "28/02/2024",
                        "13/03/2024",
                        "27/03/2024",
                        "10/04/2024",
                        "24/04/2024",
                        "08/05/2024",
                        "22/05/2024",
                        "05/06/2024",
                        "19/06/2024",
                        "03/07/2024",
                        "17/07/2024",
                        "31/07/2024",
                        "14/08/2024",
                        "28/08/2024",
                        "11/09/2024",
                        "25/09/2024",
                        "09/10/2024",
                        "23/10/2024",
                        "06/11/2024",
                        "20/11/2024",
                    ],
                    "Glass Box": [
                        "19/12/2023",
                        "17/01/2024",
                        "14/02/2024",
                        "13/03/2024",
                        "10/04/2024",
                        "08/05/2024",
                        "05/06/2024",
                        "03/07/2024",
                        "31/07/2024",
                        "28/08/2024",
                        "25/09/2024",
                        "23/10/2024",
                        "20/11/2024",
                    ],
                },
                "ThursdayG1-2024.pdf": {
                    "Black Bin": [
                        "07/12/2023",
                        "20/12/2023",
                        "04/01/2024",
                        "18/01/2024",
                        "01/02/2024",
                        "15/02/2024",
                        "29/02/2024",
                        "14/03/2024",
                        "28/03/2024",
                        "11/04/2024",
                        "25/04/2024",
                        "09/05/2024",
                        "23/05/2024",
                        "06/06/2024",
                        "20/06/2024",
                        "04/07/2024",
                        "18/07/2024",
                        "01/08/2024",
                        "15/08/2024",
                        "29/08/2024",
                        "12/09/2024",
                        "26/09/2024",
                        "10/10/2024",
                        "24/10/2024",
                        "07/11/2024",
                        "21/11/2024",
                    ],
                    "Green Bin": [
                        "14/12/2023",
                        "28/12/2023",
                        "11/01/2024",
                        "25/01/2024",
                        "08/02/2024",
                        "22/02/2024",
                        "07/03/2024",
                        "21/03/2024",
                        "04/04/2024",
                        "18/04/2024",
                        "02/05/2024",
                        "16/05/2024",
                        "30/05/2024",
                        "13/06/2024",
                        "27/06/2024",
                        "11/07/2024",
                        "25/07/2024",
                        "08/08/2024",
                        "22/08/2024",
                        "05/09/2024",
                        "19/09/2024",
                        "03/10/2024",
                        "17/10/2024",
                        "31/10/2024",
                        "14/11/2024",
                        "28/11/2024",
                    ],
                    "Glass Box": [
                        "28/12/2023",
                        "25/01/2024",
                        "22/02/2024",
                        "21/03/2024",
                        "18/04/2024",
                        "16/05/2024",
                        "13/06/2024",
                        "11/07/2024",
                        "08/08/2024",
                        "05/09/2024",
                        "03/10/2024",
                        "31/10/2024",
                        "28/11/2024",
                    ],
                },
                "ThursdayG2-2024.pdf": {
                    "Black Bin": [
                        "14/12/2023",
                        "28/12/2023",
                        "11/01/2024",
                        "25/01/2024",
                        "08/02/2024",
                        "22/02/2024",
                        "07/03/2024",
                        "21/03/2024",
                        "04/04/2024",
                        "18/04/2024",
                        "02/05/2024",
                        "16/05/2024",
                        "30/05/2024",
                        "13/06/2024",
                        "27/06/2024",
                        "11/07/2024",
                        "25/07/2024",
                        "08/08/2024",
                        "22/08/2024",
                        "05/09/2024",
                        "19/09/2024",
                        "03/10/2024",
                        "17/10/2024",
                        "31/10/2024",
                        "14/11/2024",
                        "28/11/2024",
                    ],
                    "Green Bin": [
                        "07/12/2023",
                        "20/12/2023",
                        "04/01/2024",
                        "18/01/2024",
                        "01/02/2024",
                        "15/02/2024",
                        "29/02/2024",
                        "14/03/2024",
                        "28/03/2024",
                        "11/04/2024",
                        "25/04/2024",
                        "09/05/2024",
                        "23/05/2024",
                        "06/06/2024",
                        "20/06/2024",
                        "04/07/2024",
                        "18/07/2024",
                        "01/08/2024",
                        "15/08/2024",
                        "29/08/2024",
                        "12/09/2024",
                        "26/09/2024",
                        "10/10/2024",
                        "24/10/2024",
                        "07/11/2024",
                        "21/11/2024",
                    ],
                    "Glass Box": [
                        "07/12/2023",
                        "04/01/2024",
                        "01/02/2024",
                        "29/02/2024",
                        "28/03/2024",
                        "25/04/2024",
                        "23/05/2024",
                        "20/06/2024",
                        "18/07/2024",
                        "15/08/2024",
                        "12/09/2024",
                        "10/10/2024",
                        "07/11/2024",
                    ],
                },
                "ThursdayG3-2024.pdf": {
                    "Black Bin": [
                        "07/12/2023",
                        "20/12/2023",
                        "04/01/2024",
                        "18/01/2024",
                        "01/02/2024",
                        "15/02/2024",
                        "29/02/2024",
                        "14/03/2024",
                        "28/03/2024",
                        "11/04/2024",
                        "25/04/2024",
                        "09/05/2024",
                        "23/05/2024",
                        "06/06/2024",
                        "20/06/2024",
                        "04/07/2024",
                        "18/07/2024",
                        "01/08/2024",
                        "15/08/2024",
                        "29/08/2024",
                        "12/09/2024",
                        "26/09/2024",
                        "10/10/2024",
                        "24/10/2024",
                        "07/11/2024",
                        "21/11/2024",
                    ],
                    "Green Bin": [
                        "14/12/2023",
                        "28/12/2023",
                        "11/01/2024",
                        "25/01/2024",
                        "08/02/2024",
                        "22/02/2024",
                        "07/03/2024",
                        "21/03/2024",
                        "04/04/2024",
                        "18/04/2024",
                        "02/05/2024",
                        "16/05/2024",
                        "30/05/2024",
                        "13/06/2024",
                        "27/06/2024",
                        "11/07/2024",
                        "25/07/2024",
                        "08/08/2024",
                        "22/08/2024",
                        "05/09/2024",
                        "19/09/2024",
                        "03/10/2024",
                        "17/10/2024",
                        "31/10/2024",
                        "14/11/2024",
                        "28/11/2024",
                    ],
                    "Glass Box": [
                        "14/12/2023",
                        "11/01/2024",
                        "08/02/2024",
                        "07/03/2024",
                        "04/04/2024",
                        "02/05/2024",
                        "30/05/2024",
                        "27/06/2024",
                        "25/07/2024",
                        "22/08/2024",
                        "19/09/2024",
                        "17/10/2024",
                        "14/11/2024",
                    ],
                },
                "ThursdayG4-2024.pdf": {
                    "Black Bin": [
                        "14/12/2023",
                        "28/12/2023",
                        "11/01/2024",
                        "25/01/2024",
                        "08/02/2024",
                        "22/02/2024",
                        "07/03/2024",
                        "21/03/2024",
                        "04/04/2024",
                        "18/04/2024",
                        "02/05/2024",
                        "16/05/2024",
                        "30/05/2024",
                        "13/06/2024",
                        "27/06/2024",
                        "11/07/2024",
                        "25/07/2024",
                        "08/08/2024",
                        "22/08/2024",
                        "05/09/2024",
                        "19/09/2024",
                        "03/10/2024",
                        "17/10/2024",
                        "31/10/2024",
                        "14/11/2024",
                        "28/11/2024",
                    ],
                    "Green Bin": [
                        "07/12/2023",
                        "20/12/2023",
                        "04/01/2024",
                        "18/01/2024",
                        "01/02/2024",
                        "15/02/2024",
                        "29/02/2024",
                        "14/03/2024",
                        "28/03/2024",
                        "11/04/2024",
                        "25/04/2024",
                        "09/05/2024",
                        "23/05/2024",
                        "06/06/2024",
                        "20/06/2024",
                        "04/07/2024",
                        "18/07/2024",
                        "01/08/2024",
                        "15/08/2024",
                        "29/08/2024",
                        "12/09/2024",
                        "26/09/2024",
                        "10/10/2024",
                        "24/10/2024",
                        "07/11/2024",
                        "21/11/2024",
                    ],
                    "Glass Box": [
                        "20/12/2023",
                        "18/01/2024",
                        "15/02/2024",
                        "14/03/2024",
                        "11/04/2024",
                        "09/05/2024",
                        "06/06/2024",
                        "04/07/2024",
                        "01/08/2024",
                        "29/08/2024",
                        "26/09/2024",
                        "24/10/2024",
                        "21/11/2024",
                    ],
                },
                "FridayG1-2024.pdf": {
                    "Black Bin": [
                        "08/12/2023",
                        "22/12/2023",
                        "05/01/2024",
                        "19/01/2024",
                        "02/02/2024",
                        "16/02/2024",
                        "01/03/2024",
                        "15/03/2024",
                        "29/03/2024",
                        "12/04/2024",
                        "26/04/2024",
                        "10/05/2024",
                        "24/05/2024",
                        "07/06/2024",
                        "21/06/2024",
                        "05/07/2024",
                        "19/07/2024",
                        "02/08/2024",
                        "16/08/2024",
                        "30/08/2024",
                        "13/09/2024",
                        "27/09/2024",
                        "11/10/2024",
                        "25/10/2024",
                        "08/11/2024",
                        "22/11/2024",
                    ],
                    "Green Bin": [
                        "01/12/2023",
                        "15/12/2023",
                        "29/12/2023",
                        "12/01/2024",
                        "26/01/2024",
                        "09/02/2024",
                        "23/02/2024",
                        "08/03/2024",
                        "22/03/2024",
                        "05/04/2024",
                        "19/04/2024",
                        "03/05/2024",
                        "17/05/2024",
                        "31/05/2024",
                        "14/06/2024",
                        "28/06/2024",
                        "12/07/2024",
                        "26/07/2024",
                        "09/08/2024",
                        "23/08/2024",
                        "06/09/2024",
                        "20/09/2024",
                        "04/10/2024",
                        "18/10/2024",
                        "01/11/2024",
                        "15/11/2024",
                        "29/11/2024",
                    ],
                    "Glass Box": [
                        "01/12/2023",
                        "29/12/2023",
                        "26/01/2024",
                        "23/02/2024",
                        "22/03/2024",
                        "19/04/2024",
                        "17/05/2024",
                        "14/06/2024",
                        "12/07/2024",
                        "09/08/2024",
                        "06/09/2024",
                        "04/10/2024",
                        "01/11/2024",
                        "29/11/2024",
                    ],
                },
                "FridayG2-2024.pdf": {
                    "Black Bin": [
                        "01/12/2023",
                        "15/12/2023",
                        "29/12/2023",
                        "12/01/2024",
                        "26/01/2024",
                        "09/02/2024",
                        "23/02/2024",
                        "08/03/2024",
                        "22/03/2024",
                        "05/04/2024",
                        "19/04/2024",
                        "03/05/2024",
                        "17/05/2024",
                        "31/05/2024",
                        "14/06/2024",
                        "28/06/2024",
                        "12/07/2024",
                        "26/07/2024",
                        "09/08/2024",
                        "23/08/2024",
                        "06/09/2024",
                        "20/09/2024",
                        "04/10/2024",
                        "18/10/2024",
                        "01/11/2024",
                        "15/11/2024",
                        "29/11/2024",
                    ],
                    "Green Bin": [
                        "08/12/2023",
                        "21/12/2023",
                        "05/01/2024",
                        "19/01/2024",
                        "02/02/2024",
                        "16/02/2024",
                        "01/03/2024",
                        "15/03/2024",
                        "29/03/2024",
                        "12/04/2024",
                        "26/04/2024",
                        "10/05/2024",
                        "24/05/2024",
                        "07/06/2024",
                        "21/06/2024",
                        "05/07/2024",
                        "19/07/2024",
                        "02/08/2024",
                        "16/08/2024",
                        "30/08/2024",
                        "13/09/2024",
                        "27/09/2024",
                        "11/10/2024",
                        "25/10/2024",
                        "08/11/2024",
                        "22/11/2024",
                    ],
                    "Glass Box": [
                        "08/12/2023",
                        "05/01/2024",
                        "02/02/2024",
                        "01/03/2024",
                        "29/03/2024",
                        "26/04/2024",
                        "24/05/2024",
                        "21/06/2024",
                        "19/07/2024",
                        "16/08/2024",
                        "13/09/2024",
                        "11/10/2024",
                        "08/11/2024",
                    ],
                },
                "FridayG3-2024.pdf": {
                    "Black Bin": [
                        "08/12/2023",
                        "21/12/2023",
                        "05/01/2024",
                        "19/01/2024",
                        "02/02/2024",
                        "16/02/2024",
                        "01/03/2024",
                        "15/03/2024",
                        "29/03/2024",
                        "12/04/2024",
                        "26/04/2024",
                        "10/05/2024",
                        "24/05/2024",
                        "07/06/2024",
                        "21/06/2024",
                        "05/07/2024",
                        "19/07/2024",
                        "02/08/2024",
                        "16/08/2024",
                        "30/08/2024",
                        "13/09/2024",
                        "27/09/2024",
                        "11/10/2024",
                        "25/10/2024",
                        "08/11/2024",
                        "22/11/2024",
                    ],
                    "Green Bin": [
                        "01/12/2023",
                        "15/12/2023",
                        "29/12/2023",
                        "12/01/2024",
                        "26/01/2024",
                        "09/02/2024",
                        "23/02/2024",
                        "08/03/2024",
                        "22/03/2024",
                        "05/04/2024",
                        "19/04/2024",
                        "03/05/2024",
                        "17/05/2024",
                        "31/05/2024",
                        "14/06/2024",
                        "28/06/2024",
                        "12/07/2024",
                        "26/07/2024",
                        "09/08/2024",
                        "23/08/2024",
                        "06/09/2024",
                        "20/09/2024",
                        "04/10/2024",
                        "18/10/2024",
                        "01/11/2024",
                        "15/11/2024",
                        "29/11/2024",
                    ],
                    "Glass Box": [
                        "15/12/2023",
                        "12/01/2024",
                        "09/02/2024",
                        "08/03/2024",
                        "05/04/2024",
                        "03/05/2024",
                        "31/05/2024",
                        "28/06/2024",
                        "26/07/2024",
                        "23/08/2024",
                        "20/09/2024",
                        "18/10/2024",
                        "15/11/2024",
                    ],
                },
                "FridayG4-2024.pdf": {
                    "Black Bin": [
                        "01/12/2023",
                        "15/12/2023",
                        "29/12/2023",
                        "12/01/2024",
                        "26/01/2024",
                        "09/02/2024",
                        "23/02/2024",
                        "08/03/2024",
                        "22/03/2024",
                        "05/04/2024",
                        "19/04/2024",
                        "03/05/2024",
                        "17/05/2024",
                        "31/05/2024",
                        "14/06/2024",
                        "28/06/2024",
                        "12/07/2024",
                        "26/07/2024",
                        "09/08/2024",
                        "23/08/2024",
                        "06/09/2024",
                        "20/09/2024",
                        "04/10/2024",
                        "18/10/2024",
                        "01/11/2024",
                        "15/11/2024",
                        "29/11/2024",
                    ],
                    "Green Bin": [
                        "08/12/2023",
                        "21/12/2023",
                        "05/01/2024",
                        "19/01/2024",
                        "02/02/2024",
                        "16/02/2024",
                        "01/03/2024",
                        "15/03/2024",
                        "29/03/2024",
                        "12/04/2024",
                        "26/04/2024",
                        "10/05/2024",
                        "24/05/2024",
                        "07/06/2024",
                        "21/06/2024",
                        "05/07/2024",
                        "19/07/2024",
                        "02/08/2024",
                        "16/08/2024",
                        "30/08/2024",
                        "13/09/2024",
                        "27/09/2024",
                        "11/10/2024",
                        "25/10/2024",
                        "08/11/2024",
                        "22/11/2024",
                    ],
                    "Glass Box": [
                        "21/12/2023",
                        "19/01/2024",
                        "16/02/2024",
                        "15/03/2024",
                        "12/04/2024",
                        "10/05/2024",
                        "07/06/2024",
                        "05/07/2024",
                        "02/08/2024",
                        "30/08/2024",
                        "27/09/2024",
                        "25/10/2024",
                        "22/11/2024",
                    ],
                },
            },
            "green": {
                "Garden%20Waste%20A.pdf": {"Garden Bin": ["04/03/2024", "18/03/2024"]},
                "Garden%20Waste%20B.pdf": {"Garden Bin": ["05/03/2024", "19/03/2024"]},
                "Garden%20Waste%20C.pdf": {"Garden Bin": ["06/03/2024", "20/03/2024"]},
                "Garden%20Waste%20D.pdf": {"Garden Bin": ["07/03/2024", "21/03/2024"]},
                "Garden%20Waste%20E.pdf": {"Garden Bin": ["08/03/2024", "22/03/2024"]},
                "Garden%20Waste%20F.pdf": {"Garden Bin": ["11/03/2024", "25/03/2024"]},
                "Garden%20Waste%20G.pdf": {"Garden Bin": ["12/03/2024", "26/03/2024"]},
                "Garden%20Waste%20H.pdf": {"Garden Bin": ["13/03/2024", "27/03/2024"]},
                "Garden%20Waste%20I.pdf": {"Garden Bin": ["14/03/2024", "28/03/2024"]},
                "Garden%20Waste%20J.pdf": {
                    "Garden Bin": ["01/03/2024", "15/03/2024", "29/03/2024"]
                },
            },
        }

        output = {}
        output = raw_data["refuse"][refuse]
        output["Garden Bin"] = raw_data["green"][garden]["Garden Bin"]

        return output
